import argparse
import os


def main(source):
    for root, dirs, filenames in os.walk(source):
        for f in filenames:
            file = open(os.path.join(source, f), "r")
            file_data = file.readlines()
            file.close()
            file = open(os.path.join(source, f), "w")
            file.writelines(file_data[:-1])
            file.close()


if __name__ == "__main__":
    parser = argparse.ArgumentParser(
        description="Trim Final Lines of a Particular Directory"
    )
    parser.add_argument("source")
    args = parser.parse_args()
    main(args.source)



from invoke import task


@task
def check(c):
    c.run("pipenv run flake8 .")
    c.run("pipenv run mypy .")


@task
def format(c):
    c.run("pipenv run isort . --recursive")
    c.run("pipenv run black . ")


@task
def libs(c):
    c.run("pipenv run pip list -o")
